# Generated by Django 5.1 on 2024-08-13 23:30

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_partner', '0006_partner_services'),
    ]

    operations = [
        migrations.AddField(
            model_name='position',
            name='partner',
            field=models.ForeignKey(blank=True, help_text='Partner of position', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner'),
        ),
    ]
