# Generated by Django 5.1 on 2025-01-18 04:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_partner", "0008_partner_document_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="partner",
            name="document_type",
            field=models.CharField(
                blank=True,
                choices=[
                    ("DNI", "DNI"),
                    ("CC", "CÉDULA"),
                    ("CE", "CÉDULA DE EXTRANJERÍA"),
                    ("PAS", "PASAPORTE"),
                    ("PEP", "PERMISO ESPECIAL DE PERMANENCIA"),
                    ("LICE", "LICENCIA DE CONDUCCIÓN"),
                    ("NSS", "NÚMERO DE SEGURIDAD SOCIAL"),
                    ("NIT", "NIT"),
                    ("RUT", "RUT"),
                    ("NUIP", "NUIP"),
                    ("TI", "TARJETA DE IDENTIDAD"),
                    ("OTR", "OTRO"),
                ],
                help_text="Document type of partner",
                max_length=10,
                null=True,
                verbose_name="Document type",
            ),
        ),
    ]
