# Generated by Django 5.1 on 2025-03-06 00:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_partner", "0009_alter_partner_document_type"),
    ]

    operations = [
        migrations.AddField(
            model_name="partner",
            name="signed_key",
            field=models.CharField(
                blank=True,
                help_text="Signed key of partner",
                max_length=250,
                null=True,
                verbose_name="Signed key",
            ),
        ),
    ]
