# Generated by Django 5.1 on 2025-01-17 15:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_partner", "0007_position_partner"),
    ]

    operations = [
        migrations.AddField(
            model_name="partner",
            name="document_type",
            field=models.CharField(
                blank=True,
                choices=[
                    ("DNI", "DNI"),
                    ("CC", "CÉDULA"),
                    ("CE", "CÉDULA DE EXTRANJERÍA"),
                    ("PAS", "PASAPORTE"),
                    ("PEP", "PERMISO ESPECIAL DE PERMANENCIA"),
                    ("NIT", "NIT"),
                    ("RUT", "RUT"),
                    ("NUIP", "NUIP"),
                    ("TI", "TARJETA DE IDENTIDAD"),
                    ("OTR", "OTRO"),
                ],
                help_text="Document type of partner",
                max_length=10,
                null=True,
                verbose_name="Document type",
            ),
        ),
    ]
